package MT::Plugin::ChangeTemplateBuildType;
use strict;
use MT;
use MT::Plugin;
use MT::Template;

our $VERSION = '0.1';

use base qw( MT::Plugin );

my $plugin = MT::Plugin::ChangeTemplateBuildType->new({
    id =>  'ChangeTemplateBuildType',
    key => 'changetemplatebuildtype',
    description => '<MT_TRANS phrase=\'_PLUGIN_DESCRIPTION\'>',
    name => 'ChangeTemplateBuildType',
    author_name => 'Alfasado, Inc.',
    author_link => 'http://alfasado.net/',
    'version' =>  $VERSION,
    l10n_class => 'ChangeTemplateBuildType::L10N',
});

MT->add_plugin( $plugin );

sub init_registry {
    my $plugin = shift;
    $plugin->registry( {
        callbacks => {
            'MT::App::CMS::template_output.list_template'
                 => \&_list_template,
        },
        applications => {
            cms => {
                list_actions => {
                    template => {
                        set2static => {
                            label => 'Set to Statically',
                            code => \&_changetemplatebuildtype,
                            permissions => 'can_edit_templates',
                        },
                        set2queue => {
                            label => 'Set to Publish Queue',
                            code => \&_changetemplatebuildtype,
                            permissions => 'can_edit_templates',
                        },
                        set2dynamic => {
                            label => 'Set to Dynamically',
                            code => \&_changetemplatebuildtype,
                            permissions => 'can_edit_templates',
                        },
                        set2manually => {
                            label => 'Set to Manually',
                            code => \&_changetemplatebuildtype,
                            permissions => 'can_edit_templates',
                        },
                        set2no_publish => {
                            label => 'Set to Do Not Publish',
                            code => \&_changetemplatebuildtype,
                            permissions => 'can_edit_templates',
                        },
                    },
                },
            },
        },
   } );
}

sub _changetemplatebuildtype {
    my $app = shift;
    my @id = $app->param( 'id' ) or return $app->errtrans( 'Invalid request.' );
    my $user = $app->user;
    my $perms = $app->permissions;
    my $admin = $user->is_superuser
      || ( $perms && $perms->can_administer_blog );
    my $edit_templates = $admin
      || ( $perms
        && ( $perms->edit_templates ) )
      ? 1 : 0;
    if (! $edit_templates ) {
        return $app->trans_error( 'Permission denied.' );
    }
    my $action = $app->param( 'action_name' );
    my $setting = 0;
    if ( $action eq 'set2static' ) {
        $setting = 1;
    } elsif ( $action eq 'set2manually' ) {
        $setting = 2;
    } elsif ( $action eq 'set2dynamic' ) {
        $setting = 3;
    } elsif ( $action eq 'set2queue' ) {
        $setting = 4;
    }
    for my $id ( @id ) {
        my $tmpl = MT::Template->load( $id );
        next unless defined $tmpl;
        $tmpl->build_type( $setting );
        $tmpl->save or die $tmpl->errstr;
    }
    $app->add_return_arg( saved => 1 );
    $app->call_return;
}

sub _list_template {
    my ( $cb, $app, $tmpl ) = @_;
    $$tmpl =~ s!(<form\sid="module-listing-form".*?)<option\svalue="set2static">.*?</option>!$1!s;
    $$tmpl =~ s!(<form\sid="system-listing-form".*?)<option\svalue="set2static">.*?</option>!$1!s;
    $$tmpl =~ s!(<form\sid="email-listing-form".*?)<option\svalue="set2static">.*?</option>!$1!s;
    $$tmpl =~ s!(<form\sid="module-listing-form".*?)<option\svalue="set2manually">.*?</option>!$1!s;
    $$tmpl =~ s!(<form\sid="system-listing-form".*?)<option\svalue="set2manually">.*?</option>!$1!s;
    $$tmpl =~ s!(<form\sid="email-listing-form".*?)<option\svalue="set2manually">.*?</option>!$1!s;
    $$tmpl =~ s!(<form\sid="module-listing-form".*?)<option\svalue="set2dynamic">.*?</option>!$1!s;
    $$tmpl =~ s!(<form\sid="system-listing-form".*?)<option\svalue="set2dynamic">.*?</option>!$1!s;
    $$tmpl =~ s!(<form\sid="email-listing-form".*?)<option\svalue="set2dynamic">.*?</option>!$1!s;
    $$tmpl =~ s!(<form\sid="module-listing-form".*?)<option\svalue="set2queue">.*?</option>!$1!s;
    $$tmpl =~ s!(<form\sid="system-listing-form".*?)<option\svalue="set2queue">.*?</option>!$1!s;
    $$tmpl =~ s!(<form\sid="email-listing-form".*?)<option\svalue="set2queue">.*?</option>!$1!s;
    $$tmpl =~ s!(<form\sid="module-listing-form".*?)<option\svalue="set2no_publish">.*?</option>!$1!s;
    $$tmpl =~ s!(<form\sid="system-listing-form".*?)<option\svalue="set2no_publish">.*?</option>!$1!s;
    $$tmpl =~ s!(<form\sid="email-listing-form".*?)<option\svalue="set2no_publish">.*?</option>!$1!s;
}

1;